@@ -25,3 +25,13 @@ utils::globalVariables(".env")
 utils::globalVariables("separation")
 utils::globalVariables("gap")
 utils::globalVariables("median")
+utils::globalVariables("ecdf_values")
+utils::globalVariables("group")
+utils::globalVariables("xmin_final")
+utils::globalVariables("xmin")
+utils::globalVariables("xlower")
+utils::globalVariables("xmiddle")
+utils::globalVariables("xupper")
+utils::globalVariables("xmax")
+utils::globalVariables("xmax_final")
+utils::globalVariables("outliers")
